==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
var GotFocusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GotFocusEventArgsDescriptionMetadata, _super);
    function GotFocusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GotFocusEventArgsDescriptionMetadata.b = function (a) {
        if (GotFocusEventArgsDescriptionMetadata.a == null) {
            GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
        }
        if (a.k(GotFocusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GotFocusEventArgsDescriptionMetadata.a);
    };
    GotFocusEventArgsDescriptionMetadata.c = function (a) {
    };
    GotFocusEventArgsDescriptionMetadata.d = function (a) {
        GotFocusEventArgsDescriptionMetadata.b(a);
        a.ac("GotFocusEventArgs", function () { return new GotFocusEventArgsDescription(); });
        a.ab("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
    };
    GotFocusEventArgsDescriptionMetadata.$t = markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
}(Base));
export { GotFocusEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
var GotFocusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GotFocusEventArgsDescriptionMetadata, _super);
    function GotFocusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GotFocusEventArgsDescriptionMetadata.b = function (a) {
        if (GotFocusEventArgsDescriptionMetadata.a == null) {
            GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
        }
        if (a.k(GotFocusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GotFocusEventArgsDescriptionMetadata.a);
    };
    GotFocusEventArgsDescriptionMetadata.c = function (a) {
    };
    GotFocusEventArgsDescriptionMetadata.d = function (a) {
        GotFocusEventArgsDescriptionMetadata.b(a);
        a.ae("GotFocusEventArgs", function () { return new GotFocusEventArgsDescription(); });
        a.ad("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
    };
    GotFocusEventArgsDescriptionMetadata.$t = markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
}(Base));
export { GotFocusEventArgsDescriptionMetadata };
